==> mingw-w64-ogre3d-13.6.3-1.src.tar.zst: ogre-13.6.3/PlugIns/EXRCodec/src/O_IStream.cpp <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2014 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#include "O_IStream.h"
#include <Iex.h>
using namespace Imf;


namespace Ogre {

bool O_IStream::read(char c[], int n) {
    size_t s = _stream.read(c, n);
    if(s != size_t(n))
        throw Iex::InputExc ("Unexpected end of file.");
    return _stream.eof();
}

Int64 O_IStream::tellg() {
    return _stream.getCurrentPtr() - _stream.getPtr();
}

void O_IStream::seekg(Int64 pos) {
    _stream.seek(pos);
}

void O_IStream::clear() {
    /* Clear error flags -- there are no error flags */
}


};

==> mingw-w64-ogre3d-14.3.0-1.src.tar.zst: ogre-14.3.0/PlugIns/EXRCodec/src/O_IStream.cpp <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2014 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#include "O_IStream.h"
#include <Iex.h>
using namespace Imf;


namespace Ogre {

bool O_IStream::read(char c[], int n) {
    size_t s = _stream.read(c, n);
    if(s != size_t(n))
        throw Iex::InputExc ("Unexpected end of file.");
    return _stream.eof();
}

uint64_t O_IStream::tellg() {
    return _stream.getCurrentPtr() - _stream.getPtr();
}

void O_IStream::seekg(uint64_t pos) {
    _stream.seek(pos);
}

void O_IStream::clear() {
    /* Clear error flags -- there are no error flags */
}


};
